use crate::controllers::HttpResult;
use crate::extractors::accommodation_extractor::FamilyAndAccommodationInPath;
use crate::extractors::accommodation_reservation_extractor::FamilyAndAccommodationReservationInPath;
use crate::extractors::family_extractor::FamilyInPath;
use crate::services::accommodations_reservations_service;
use actix_web::HttpResponse;

/// Get the reservations for a given accommodation
pub async fn get_accommodation_reservations(a: FamilyAndAccommodationInPath) -> HttpResult {
    Ok(HttpResponse::Ok()
        .json(accommodations_reservations_service::get_all_of_accommodation(a.id()).await?))
}

/// Get the full list of accommodations reservations for a family
pub async fn full_list(m: FamilyInPath) -> HttpResult {
    Ok(HttpResponse::Ok()
        .json(accommodations_reservations_service::get_all_of_family(m.family_id()).await?))
}

/// Get a single accommodation reservation
pub async fn get_single(m: FamilyAndAccommodationReservationInPath) -> HttpResult {
    Ok(HttpResponse::Ok().json(m.to_reservation()))
}
